@@ -5,7 +5,8 @@ package Lemonldap::NG::Manager::_HTML;
 # comes for the first time.
 
 use AutoLoader qw(AUTOLOAD);
-our $VERSION = '0.1';
+require Lemonldap::NG::Manager::_i18n;
+our $VERSION = '0.13';
 
 1;
 __END__
@@ -68,6 +69,13 @@ EOT
 
 sub javascript {
     my $self = shift;
+    Lemonldap::NG::Manager::_i18n::import( $ENV{HTTP_ACCEPT_LANGUAGE} );
+    my %text;
+    foreach(qw(newVirtualHost newMacro newGroup newVar newGSOpt saveConf
+               deleteNode locationRules unableToSave confSaved saveFailure
+               newRule newHeader)) {
+        $text{$_} = &{"txt_$_"};
+    }
     print <<EOT;
 var s3,s32;
 window.onload=function(){
@@ -122,19 +130,19 @@ function onNodeSelect(nodeId) {
   }
   var but='';
   if(nodeIs(nodeId,"virtualHosts")){
-    but+=button('Nouvel Hte Virtuel','newVirtualHost',nodeId);
+    but+=button('$text{newVirtualHost}','newVirtualHost',nodeId);
     if(nodeIs(nodeId,"virtualHost")){
-      but+=button('Nouvelle rgle','newRule',nodeId);
-      but+=button('Nouvel en-tte','newHeader',nodeId);
+      but+=button('$text{newRule}','newRule',nodeId);
+      but+=button('$text{newHeader}','newHeader',nodeId);
     }
     help('virtualHosts');
   }
   else if(nodeIs(nodeId,"macros")){
-    but+=button('Nouvelle macro','newMacro',nodeId);
+    but+=button('$text{newMacro}','newMacro',nodeId);
     help('macros');
   }
   else if(nodeIs(nodeId,"groups")){
-    but+=button('Nouveau groupe','newGroup',nodeId);
+    but+=button('$text{newGroup}','newGroup',nodeId);
     help('groups');
   }
   else if(nodeIs(nodeId,"generalParameters")){
@@ -142,18 +150,27 @@ function onNodeSelect(nodeId) {
       help('ldap');
     }
     else if(nodeIs(nodeId,"exportedVars")){
-      but+=button('Nouvelle variable','newVar',nodeId);
+      but+=button('$text{newVar}','newVar',nodeId);
       help('vars');
     }
     else if(nodeIs(nodeId,'sessionStorage')){
       if(nodeIs(nodeId,"globalStorageOptions")){
-        but+=button('Nouvelle option','newGSOpt',nodeId);
+        but+=button('$text{newGSOpt}','newGSOpt',nodeId);
       }
       help('storage');
     }
+    else if(nodeIs(nodeId,'authParams')){
+      help('authParams');
+    }
+    else if(nodeIs(nodeId,'cookieName')){
+      help('cookieName');
+    }
+    else if(nodeIs(nodeId,'domain')){
+      help('domain');
+    }
   }
-  if(tree.getUserData(nodeId,"modif")=='both') but+=button("Supprimer",'deleteNode',nodeId);
-  but+=button('Sauvegarder','saveConf');
+  if(tree.getUserData(nodeId,"modif")=='both') but+=button('$text{deleteNode}','deleteNode',nodeId);
+  but+=button('$text{saveConf}','saveConf');
   document.getElementById('buttons').innerHTML = but;
 }
 
@@ -181,15 +198,15 @@ function insertNewChild(a,b,c) {
 }
 
 function newVirtualHost() {
-  var rep=prompt("Nouvel hte virtuel");
+  var rep=prompt("$text{newVirtualHost}");
   if(rep) {
     insertNewChild('virtualHosts',rep,rep)
     tree.setUserData(rep,'modif','text');
-    insertNewChild(rep,rep+'_exportedHeaders','Headers');
+    insertNewChild(rep,rep+'_exportedHeaders','$text{httpHeaders}');
     insertNewChild(rep+'_exportedHeaders',rep+'_exportedHeaders_1','Auth-User');
     tree.setUserData(rep+'_exportedHeaders_1','modif','both');
     tree.setUserData(rep+'_exportedHeaders_1','value','\$uid');
-    insertNewChild(rep,rep+'_locationRules','Rgles');
+    insertNewChild(rep,rep+'_locationRules','$text{locationRules}');
     insertNewChild(rep+'_locationRules',rep+'_locationRules_default','default');
     tree.setUserData(rep+'_locationRules_default','modif','value');
     tree.setUserData(rep+'_locationRules_default','value','deny');
@@ -241,7 +258,7 @@ if(window.XMLHttpRequest) // Firefox
 else if(window.ActiveXObject) // Internet Explorer 
   xhr_object = new ActiveXObject("Microsoft.XMLHTTP"); 
 else { // XMLHttpRequest non support par le navigateur 
-  alert("Votre navigateur ne supporte pas les objets XMLHTTPRequest: sauvegarde impossible."); 
+  alert('$text{unableToSave}');
 } 
 
 function help(s){
@@ -263,13 +280,13 @@ function saveConf(){
       var r=xhr_object.responseText;
       if(r>0) {
         tree.setItemText('root','Configuration '+r);
-        document.getElementById('help').innerHTML='<h3>Configuration sauvegarde sous le numro : '+r+'</h3>';
+        document.getElementById('help').innerHTML='<h3>$text{confSaved} : '+r+'</h3>';
       }
       else {
-        document.getElementById('help').innerHTML='<h3>chec de la sauvegarde</h3>';
+        document.getElementById('help').innerHTML='<h3>$text{saveFailure}</h3>';
       }
     }
-    else  document.getElementById('help').innerHTML='<h3>chec de la sauvegarde</h3>';
+    else  document.getElementById('help').innerHTML='<h3>$text{saveFailure}</h3>';
   }
   xhr_object.send(h);
 }
@@ -277,6 +294,7 @@ function saveConf(){
 function tree2txt(id){
   var s=tree.getSubItems(id);
   var c=s.split(',');
+  id = id.replace(/^[0-9]*_/,'');
   var r='<'+id+"><text>"+ec(tree.getItemText(id))+"</text>\\n";
   if((!s) || s=='' || c.length==0){
     r+= '<value>'+ec(tree.getUserData(id,'value'))+"</value>\\n";
